==> tool-sql-2.6.0-pre3-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/StateMachineStateSet.java <==
package io.ciera.tool.sql.ooaofooa.statemachine;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.statemachine.StateSet;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;


public interface StateMachineStateSet extends IInstanceSet<StateMachineStateSet,StateMachineState> {

    // attributes
    public void setSMstt_ID( UniqueId m_SMstt_ID ) throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException;
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException;
    public void setFinal( int m_Final ) throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;


    // selections
    public I_INSSet R2915_defines_state_of_I_INS() throws XtumlException;
    public StateSet R4758_is_transformed_from_State() throws XtumlException;
    public SM_SMSet R501_SM_SM() throws XtumlException;
    public StateEventMatrixEntrySet R503_receives_StateEventMatrixEntry() throws XtumlException;
    public TransitionSet R506_is_destination_of_Transition() throws XtumlException;
    public NoEventTransitionSet R508_is_origination_of_NoEventTransition() throws XtumlException;
    public MooreActionHomeSet R511_MooreActionHome() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/StateMachineStateSet.java <==
package io.ciera.tool.sql.ooaofooa.statemachine;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.statemachine.StateSet;
import io.ciera.tool.sql.ooaofooa.instance.I_INSSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.NoEventTransitionSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.StateEventMatrixEntrySet;
import io.ciera.tool.sql.ooaofooa.statemachine.TransitionSet;


public interface StateMachineStateSet extends IInstanceSet<StateMachineStateSet,StateMachineState> {

    // attributes
    public void setSMspd_IDdeprecated( UniqueId m_SMspd_IDdeprecated ) throws XtumlException;
    public void setSMstt_ID( UniqueId m_SMstt_ID ) throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;
    public void setFinal( int m_Final ) throws XtumlException;
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;


    // selections
    public I_INSSet R2915_defines_state_of_I_INS() throws XtumlException;
    public StateSet R4758_State() throws XtumlException;
    public SM_SMSet R501_SM_SM() throws XtumlException;
    public StateEventMatrixEntrySet R503_receives_StateEventMatrixEntry() throws XtumlException;
    public TransitionSet R506_is_destination_of_Transition() throws XtumlException;
    public NoEventTransitionSet R508_is_origination_of_NoEventTransition() throws XtumlException;
    public MooreActionHomeSet R511_MooreActionHome() throws XtumlException;


}
